pub async fn get_plan_for_user(
conn: &mut PgConnection,
plan_id: Uuid,
user_id: Uuid,
) -> ModelResult<CourseDesignerPlan>Expand description
Loads a single plan if user is a member.
pub async fn get_plan_for_user(
conn: &mut PgConnection,
plan_id: Uuid,
user_id: Uuid,
) -> ModelResult<CourseDesignerPlan>Loads a single plan if user is a member.